@@ -36,6 +36,7 @@
 #define _D_BT_CONTEXT_H_
 
 #include "DownloadContext.h"
+
 #include <utility>
 #include <deque>
 
@@ -49,8 +50,6 @@ class RequestGroup;
 class BtContext:public DownloadContext {
 protected:
   bool _private;
-
-  IntSequence _fileFilter;
 public:
   BtContext():_private(false) {}
   
@@ -87,37 +86,7 @@ public:
 
   virtual const std::string& getName() const = 0;
 
-  void setFileFilter(const IntSequence& seq);
-
-  IntSequence getFileFilter() const;
-
-  static const std::string C_NAME;
-
-  static const std::string C_FILES;
-
-  static const std::string C_LENGTH;
-
-  static const std::string C_PATH;
-
-  static const std::string C_INFO;
-
-  static const std::string C_PIECES;
-
-  static const std::string C_PIECE_LENGTH;
-
-  static const std::string C_PRIVATE;
-
-  // This is just a string "1". Used as a value of "private" flag.
-  static const std::string C_PRIVATE_ON;
-
-  static const std::string C_URL_LIST;
-
-  static const std::string C_ANNOUNCE;
-
-  static const std::string C_ANNOUNCE_LIST;
-
-  static const std::string C_NODES;
-
+  virtual void setFileFilter(IntSequence seq) = 0;
 };
 
 class BtContext;
